@@ -25,4 +25,10 @@ class DimensionTestSuite(BaseTestSuite):
             self.TestSuite.addTest(CommonTestCase(self.TableDataFrame, self.FieldInfo, self.CustomEvents, name))
 
     def run_tests(self) -> None:
-        self.TestRunner.run(self.TestSuite)
\ No newline at end of file
+
+        self.TestRunner.run(self.TestSuite)
+
+        for event in self.CustomEvents:
+            print(str(event))
+
+        self.dump_events()
\ No newline at end of file
